@@ -310,11 +310,17 @@ def test_os_build_compare():
     assert not res
     res = utils.version_compare("0.23.22-1.amzn2.0.1", 0, "*", None, "0.23.22")
     assert not res
+    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1.e")
+    assert not res
 
 
 def test_ubuntu_openssl():
-    res = utils.version_compare("1.1.1f-1ubuntu2.8", 0, "*", None, "1.1.1.e")
-    assert not res
+    res = utils.version_compare("1.10-0ubuntu4", 0, "*", None, "1.10-0ubuntu4.1")
+    assert res
+    res = utils.version_compare("2.2.19-3ubuntu2.1", 0, "*", None, "*")
+    assert res
+    res = utils.version_compare("2.2.19-3ubuntu2.1", 0, "*", None, None)
+    assert res
 
 
 def test_debian_build_compare():
