@@ -33,6 +33,7 @@ except ImportError:
 json_lib = orjson if ORJSON_AVAILABLE else json
 
 threat_to_severity = {
+    "negligible": "LOW",
     "low": "LOW",
     "severity_low": "LOW",
     "medium": "MEDIUM",
@@ -323,15 +324,17 @@ class AquaSource(NvdSource):
             description = cve_data.get("UbuntuDescription")
         assigner = "ubuntu"
         vendor = "ubuntu"
-        severity = cve_data.get("Priority").upper()
+        severity = threat_to_severity[cve_data.get("Priority").lower()]
         score, severity, vectorString, attackComplexity = get_default_cve_data(severity)
         exploitabilityScore = score
         publishedDate = cve_data.get("PublicDate")
         lastModifiedDate = cve_data.get("PublicDate")
         for pkg_name, distro_obj in packages.items():
             for distro_name, status_obj in distro_obj.items():
-                # Skip devel branch and those without version numbers
-                if not status_obj.get("Note") or distro_name in ("devel"):
+                if distro_name in ("devel") or status_obj.get("Status") in (
+                    "ignored",
+                    "needs-triage",
+                ):
                     continue
                 version_start_including = ""
                 version_end_including = ""
@@ -345,6 +348,7 @@ class AquaSource(NvdSource):
                 # Remove epoch
                 if ":" in fix_note:
                     fix_note = fix_note.split(":")[-1]
+                # Released CVEs have fixes
                 if (
                     status_obj.get("Status")
                     in (
@@ -356,7 +360,10 @@ class AquaSource(NvdSource):
                 ):
                     fix_version_start_including = fix_note
                     version_end_excluding = fix_note
-                if pkg_name and fix_version_start_including:
+                # Handle CVEs that are deferred
+                if status_obj.get("Status") in ("deferred") and " " not in fix_note:
+                    version_end_including = "99.99.9"
+                if pkg_name and (fix_version_start_including or version_end_including):
                     tdata = config.CVE_TPL % dict(
                         cve_id=cve_id,
                         cwe_id=cwe_id,
