@@ -462,11 +462,11 @@ def version_compare(
     )
     if epoch_mode_detected:
         (
-            compare_ver,
-            min_version,
-            max_version,
-            min_affected_version_excluding,
-            max_affected_version_excluding,
+            tcompare_ver,
+            tmin_version,
+            tmax_version,
+            tmin_affected_version_excluding,
+            tmax_affected_version_excluding,
         ) = trim_epoch(
             compare_ver,
             min_version,
@@ -474,6 +474,28 @@ def version_compare(
             min_affected_version_excluding,
             max_affected_version_excluding,
         )
+        # 1.10-0ubuntu4 < 1.10-0ubuntu4.1
+        if (
+            tcompare_ver == tmax_version
+            or tcompare_ver == tmax_affected_version_excluding
+        ):
+            if (
+                max_version
+                and max_version.startswith(compare_ver)
+                and max_version != compare_ver
+            ):
+                return True
+            if (
+                max_affected_version_excluding
+                and max_affected_version_excluding.startswith(compare_ver)
+                and max_affected_version_excluding != compare_ver
+            ):
+                return True
+        compare_ver = tcompare_ver
+        min_version = tmin_version
+        max_version = tmax_version
+        min_affected_version_excluding = tmin_affected_version_excluding
+        max_affected_version_excluding = tmax_affected_version_excluding
     # Semver compatible and including versions provided
     is_min_exclude = False
     is_max_exclude = False
